@@ -17,14 +17,14 @@
 #' privileges on a MySQL server, in which case the \code{\link{useMySQL}}
 #' method can be used to insert the annotations from an EnsDB package into
 #' a MySQL database.
-#' 
+#'
 #' @param x Either a character specifying the \emph{SQLite} database file, or
 #'     a \code{DBIConnection} to e.g. a MariaDB/MySQL database.
-#' 
+#'
 #' @return A \code{\linkS4class{EnsDb}} object.
-#' 
+#'
 #' @author Johannes Rainer
-#' 
+#'
 #' @examples
 #' ## "Standard" way to create an EnsDb object:
 #' library(EnsDb.Hsapiens.v86)
@@ -90,13 +90,6 @@ EnsDb <- function(x){
     EDB
 }
 
-## loadEnsDb <- function(x) {
-##     ## con <- ensDb( x )
-##     ## EDB <- new( "EnsDb", ensdb=con )
-##     return(EnsDb(x))
-## }
-
-
 ## x is the connection to the database, name is the name of the entry to fetch
 .getMetaDataValue <- function(x, name){
     return(dbGetQuery(x, paste0("select value from metadata where name='",
@@ -326,7 +319,7 @@ addRequiredTables <- function(x, tab){
         ## add the columns needed for the filter
         filtercolumns <- unlist(lapply(filter, ensDbColumn, x))
         ## remove the prefix (column name for these)
-        filtercolumns <- sapply(filtercolumns, removePrefix, USE.NAMES = FALSE)
+        filtercolumns <- removePrefix(filtercolumns)
         columns <- unique(c(columns, filtercolumns))
     }
     ## 2) get all column names for the order.by:
@@ -350,7 +343,6 @@ addRequiredTables <- function(x, tab){
                                      startWith = startWith)
     ## b) the filter part of the query
     if (length(filter) > 0) {
-        ## USE THE ensDbQuery method here!!!
         filterquery <- paste0(" where ", ensDbQuery(filter, x,
                                                     with.tables = need.tables))
     } else {
@@ -382,16 +374,14 @@ addRequiredTables <- function(x, tab){
            )
 }
 
-
 ## remove the prefix again...
-removePrefix <- function(x, split=".", fixed=TRUE){
-    return(sapply(x, function(z){
+removePrefix <- function(x, split=".", fixed = TRUE) {
+    vapply(x, function(z) {
         tmp <- unlist(strsplit(z, split=split, fixed=fixed))
-        return(tmp[ length(tmp) ])
-    }))
+        tmp[length(tmp)]
+    }, character(1), USE.NAMES = FALSE)
 }
 
-
 ## just to add another layer; basically just calls buildQuery and executes the
 ## query
 ## join: what type of join should be performed.
@@ -405,8 +395,8 @@ removePrefix <- function(x, split=".", fixed=TRUE){
     ## column and filling it later with the values from tx_id.
     fetchColumns <- columns
     if(any(columns == "tx_name"))
-        fetchColumns <- unique(c("tx_id",
-                                 fetchColumns[fetchColumns != "tx_name"]))
+        fetchColumns <- unique(
+            c("tx_id", fetchColumns[fetchColumns != "tx_name"]))
     if (!is(filter, "AnnotationFilterList"))
         stop("parameter 'filter' has to be an 'AnnotationFilterList'!")
     ## Add also the global filter if present.
@@ -432,7 +422,7 @@ removePrefix <- function(x, split=".", fixed=TRUE){
                          skip.order.check = skip.order.check, join = join,
                          startWith = startWith)
         ## Get the data
-        ## cat("Query: ", Q, "\n")
+        ## message("Query: ", Q, "\n")
         Res <- dbGetQuery(dbconn(x), Q)
         ## Note: we can only order by the columns that we did get back from the
         ## database; that might be different for the SQL sorting!
@@ -446,10 +436,9 @@ removePrefix <- function(x, split=".", fixed=TRUE){
                          skip.order.check = skip.order.check, join = join,
                          startWith = startWith)
         ## Get the data
-        ## cat("Query: ", Q, "\n")
+        ## message("Query: ", Q, "\n")
         Res <- dbGetQuery(dbconn(x), Q)
     }
-    ## cat("Query:\n", Q, "\n")
     if(any(columns == "tx_cds_seq_start")) {
         if (!is.integer(Res[, "tx_cds_seq_start"])) {
             suppressWarnings(
@@ -466,7 +455,7 @@ removePrefix <- function(x, split=".", fixed=TRUE){
                 ## column contains "NULL" if not defined and coordinates are
                 ## characters as.numeric transforms "NULL" into NA, and ensures
                 ## coords are numeric.
-                Res[ , "tx_cds_seq_end" ] <- as.integer(Res[ , "tx_cds_seq_end" ])
+                Res[ , "tx_cds_seq_end" ] <- as.integer(Res[ , "tx_cds_seq_end"])
             )
         }
     }
@@ -481,12 +470,10 @@ removePrefix <- function(x, split=".", fixed=TRUE){
                 Res[, the_col] <- as.integer(Res[, the_col])
     }
     ## Resolving the "symlinks" again.
-    if(any(columns == "tx_name")) {
+    if (any(columns == "tx_name"))
         Res <- data.frame(Res, tx_name = Res$tx_id, stringsAsFactors = FALSE)
-    }
-    if(any(columns == "symbol")) {
+    if(any(columns == "symbol"))
         Res <- data.frame(Res, symbol = Res$gene_name, stringsAsFactors = FALSE)
-    }
     ## Ensure that the ordering is as requested.
     Res <- Res[, columns, drop=FALSE]
     Res
@@ -526,6 +513,24 @@ removePrefix <- function(x, split=".", fixed=TRUE){
                               chromosome = c("seq_name", "seq_length",
                                              "is_circular"),
                               entrezgene = c("gene_id", "entrezid"),
+                              metadata = c("name", "value")),
+                          `2.2` = list(
+                              gene = c("gene_id", "gene_name",
+                                       "gene_biotype", "gene_seq_start",
+                                       "gene_seq_end", "seq_name", "seq_strand",
+                                       "seq_coord_system", "description",
+                                       "gene_id_version",
+                                       "canonical_transcript"),
+                              tx = c("tx_id", "tx_biotype", "tx_seq_start",
+                                     "tx_seq_end", "tx_cds_seq_start",
+                                     "tx_cds_seq_end", "tx_external_name",
+                                     "gene_id"),
+                              tx2exon = c("tx_id", "exon_id", "exon_idx"),
+                              exon = c("exon_id", "exon_seq_start",
+                                       "exon_seq_end"),
+                              chromosome = c("seq_name", "seq_length",
+                                             "is_circular"),
+                              entrezgene = c("gene_id", "entrezid"),
                               metadata = c("name", "value"))
                           )
     .ENSDB_TABLES[[version]]
@@ -544,6 +549,18 @@ removePrefix <- function(x, split=".", fixed=TRUE){
                                                          "prot_dom_start",
                                                          "prot_dom_end")),
                                   `2.0` = list(
+                                      protein = c("tx_id", "protein_id",
+                                                  "protein_sequence"),
+                                      uniprot = c("protein_id", "uniprot_id",
+                                                  "uniprot_db",
+                                                  "uniprot_mapping_type"),
+                                      protein_domain = c("protein_id",
+                                                         "protein_domain_id",
+                                                         "protein_domain_source",
+                                                         "interpro_accession",
+                                                         "prot_dom_start",
+                                                         "prot_dom_end")),
+                                  `2.1` = list(
                                       protein = c("tx_id", "protein_id",
                                                   "protein_sequence"),
                                       uniprot = c("protein_id", "uniprot_id",
@@ -558,12 +575,12 @@ removePrefix <- function(x, split=".", fixed=TRUE){
                                   )
     .ENSDB_PROTEIN_TABLES[[version]]
 }
-    
+
 #' @description Extract the database schema version if available in the metadata
 #'     database column.
 #'
 #' @param x Can be either a connection object or an \code{EnsDb} object.
-#' 
+#'
 #' @noRd
 dbSchemaVersion <- function(x) {
     if (is(x, "EnsDb")) {
@@ -703,7 +720,8 @@ feedEnsDb2MySQL <- function(x, mysql, verbose = TRUE) {
     idxType <- c(chromosome = "unique", gene = "unique", gene = "", gene = "",
                  tx = "unique", tx = "", exon = "unique", tx2exon = "",
                  tx2exon = "")
-    if (as.numeric(dbSchemaVersion(con)) > 1) {
+    tbls <- dbListTables(con)
+    if (any(tbls == "entrezgene")) {
         indexCols <- c(indexCols,
                        entrezgene = "gene_id", entrezgene = "entrezid")
         idxType <- c(idxType, entrezgene = "", entrezgene = "")
@@ -748,27 +766,27 @@ feedEnsDb2MySQL <- function(x, mysql, verbose = TRUE) {
 #' method. EnsDb databases in a MariaDB/MySQL server follow the same naming
 #' conventions than EnsDb packages, with the exception that the name is all
 #' lower case and that each \code{"."} is replaced by \code{"_"}.
-#' 
+#'
 #' @param dbcon A \code{DBIConnection} object providing access to a
 #'     MariaDB/MySQL database. Either \code{dbcon} or all of the other
 #'     arguments have to be specified.
-#' 
+#'
 #' @param host Character specifying the host on which the MySQL server is
 #'     running.
-#' 
+#'
 #' @param port The port of the MariaDB/MySQL server (usually \code{3306}).
-#' 
+#'
 #' @param user The username for the MariaDB/MySQL server.
-#' 
+#'
 #' @param pass The password for the MariaDB/MySQL server.
-#' 
+#'
 #' @return A \code{data.frame} listing the database names, organism name
 #'     and Ensembl version of the EnsDb databases found on the server.
-#' 
+#'
 #' @author Johannes Rainer
-#' 
+#'
 #' @seealso \code{\link{useMySQL}}
-#' 
+#'
 #' @examples
 #' \dontrun{
 #' library(RMariaDB)
@@ -811,4 +829,3 @@ listEnsDbs <- function(dbcon, host, port, user, pass) {
         return("and")
     return(NULL)
 }
-
