@@ -124,7 +124,7 @@ makeEnsemblSQLiteFromTables <- function(path=".", dbname){
     }
     rm(tmp)
     message("OK")
-    
+
     if (as.numeric(info[info$name == "DBSCHEMAVERSION", "value"]) > 1) {
         message("Processing 'entrezgene' table ... ", appendLF = FALSE)
         ## process genes: some gene names might have fancy names...
@@ -135,7 +135,7 @@ makeEnsemblSQLiteFromTables <- function(path=".", dbname){
         rm(tmp)
         message("OK")
     }
-    
+
     message("Processing 'trancript' table ... ", appendLF = FALSE)
     ## process transcripts:
     tmp <- read.table(paste0(path, .Platform$file.sep, "ens_tx.txt"),
@@ -167,6 +167,8 @@ makeEnsemblSQLiteFromTables <- function(path=".", dbname){
         })
         tmp$tx_support_level <- unlist(tsl, use.names = FALSE)
     }
+    if (any(colnames(tmp) == "tx_external_name"))
+        tmp$tx_external_name[which(tmp$tx_external_name == "")] <- NA_character_
     dbWriteTable(con, name="tx", tmp, row.names=FALSE)
     rm(tmp)
     message("OK")
@@ -343,7 +345,7 @@ ensDbFromGtf <- function(gtf, outfile, path, organism, genomeVersion,
     }
     ## processing the metadata:
     ## first read the header...
-    tmp <- readLines(gtf, n = 10)
+    tmp <- .read_lines_compressed(gtf, n = 10)
     tmp <- tmp[grep(tmp, pattern = "^#")]
     haveHeader <- FALSE
     if (length(tmp) > 0) {
@@ -391,7 +393,7 @@ ensDbFromGtf <- function(gtf, outfile, path, organism, genomeVersion,
     gtfFilename <- gtfFilename[length(gtfFilename)]
     ## updating the Metadata information...
     lite <- dbDriver("SQLite")
-    con <- dbConnect(lite, dbname = dbname )
+    con <- dbConnect(lite, dbname = dbname)
     bla <- dbExecute(con, paste0("update metadata set value='",
                                  gtfFilename, "' where name='source_file';"))
     dbDisconnect(con)
@@ -534,7 +536,7 @@ ensDbFromGff <- function(gff, outfile, path, organism, genomeVersion,
     orgFromFile <- Parms["organism"]
     genFromFile <- Parms["genomeVersion"]
     ## Reading some info from the header.
-    tmp <- readLines(gff, n=500)
+    tmp <- .read_lines_compressed(gff, n = 500)
     if(length(grep(tmp[1], pattern="##gff-version")) == 0)
         stop("File ", gff, " does not seem to be a correct GFF file! ",
              "The ##gff-version line is missing!")
@@ -737,16 +739,7 @@ ensDbFromGRanges <- function(x, outfile, path, organism, genomeVersion,
     }
 
     con <- dbConnect(dbDriver("SQLite"), dbname=dbname)
-    on.exit(dbDisconnect(con))
-    ## ----------------------------
-    ## metadata table:
-    message("Processing metadata ... ", appendLF=FALSE)
-    Metadata <- buildMetadata(organism, version, host="unknown",
-                              sourceFile="GRanges object",
-                              genomeVersion=genomeVersion)
-    dbWriteTable(con, name="metadata", Metadata, overwrite=TRUE,
-                 row.names=FALSE)
-    message("OK")
+    on.exit(suppressWarnings(dbDisconnect(con)))
     ## Check if we've got column "type"
     if(!any(colnames(mcols(x)) == "type"))
         stop("The GRanges object lacks the required column 'type', sorry.")
@@ -826,7 +819,8 @@ ensDbFromGRanges <- function(x, outfile, path, organism, genomeVersion,
     message("Processing transcripts ... ", appendLF=TRUE)
     ## want to have: tx_id, tx_biotype, tx_seq_start, tx_seq_end, tx_cds_seq_start,
     ##               tx_cds_seq_end, gene_id
-    wouldBeNice <- c("transcript_id", "gene_id", txBiotypeCol)
+    wouldBeNice <- c("transcript_id", "gene_id",
+                     txBiotypeCol, "transcript_name")
     dontHave <- wouldBeNice[!(wouldBeNice %in% gotColumns)]
     if(length(dontHave) > 0){
         mess <- paste0("I'm missing column(s): ", paste0(sQuote(dontHave),
@@ -866,7 +860,8 @@ ensDbFromGRanges <- function(x, outfile, path, organism, genomeVersion,
         colnames(tx) <- c(cn, dontHave)
     }
     ## Add columns for UTR
-    tx <- cbind(tx, tx_cds_seq_start=rep(NA, nrow(tx)), tx_cds_seq_end=rep(NA, nrow(tx)))
+    tx <- cbind(tx, tx_cds_seq_start=rep(NA, nrow(tx)),
+                tx_cds_seq_end=rep(NA, nrow(tx)))
     ## Process CDS...
     if(any(gotTypes == "CDS")){
         ## Only do that if we've got type == "CDS"!
@@ -893,10 +888,13 @@ ensDbFromGRanges <- function(x, outfile, path, organism, genomeVersion,
         warning(mess)
     }
     colnames(tx) <- c("tx_seq_start", "tx_seq_end", "tx_id", "gene_id",
-                      "tx_biotype", "tx_cds_seq_start", "tx_cds_seq_end")
+                      "tx_biotype", "tx_external_name",
+                      "tx_cds_seq_start", "tx_cds_seq_end")
     ## rearranging data.frame:
-    tx <- tx[ , c("tx_id", "tx_biotype", "tx_seq_start", "tx_seq_end",
-                  "tx_cds_seq_start", "tx_cds_seq_end", "gene_id")]
+    tx <- tx[ , c("tx_id", "tx_external_name", "tx_biotype", "tx_seq_start",
+                  "tx_seq_end", "tx_cds_seq_start", "tx_cds_seq_end",
+                  "gene_id")]
+    ## Add transcript name.
     ## write the table.
     OK <- .checkIntegerCols(tx)
     dbWriteTable(con, name="tx", tx, overwrite=TRUE, row.names=FALSE)
@@ -966,12 +964,23 @@ ensDbFromGRanges <- function(x, outfile, path, organism, genomeVersion,
     dbWriteTable(con, name="chromosome", chroms, overwrite=TRUE, row.names=FALSE)
     rm(genes)
     message("OK")
+    ## ----------------------------
+    ## metadata table:
+    message("Processing metadata ... ", appendLF=FALSE)
+    Metadata <- buildMetadata(organism, version, host="unknown",
+                              sourceFile="GRanges object",
+                              genomeVersion=genomeVersion,
+                              schema = "1.0")
+    dbWriteTable(con, name="metadata", Metadata, overwrite=TRUE,
+                 row.names=FALSE)
+    message("OK")
     message("Generating index ... ", appendLF=FALSE)
     ## generating all indices...
     .createEnsDbIndices(con)
     message("OK")
     message("  -------------")
     message("Verifying validity of the information in the database:")
+    dbDisconnect(con)
     checkValidEnsDb(EnsDb(dbname))
     return(dbname)
 }
@@ -1062,7 +1071,7 @@ tryGetSeqinfoFromEnsembl <- function(organism, ensemblVersion, seqnames,
 }
 
 buildMetadata <- function(organism="", ensemblVersion="", genomeVersion="",
-                          host="", sourceFile=""){
+                          host="", sourceFile="", schema = "1.0"){
     MetaData <- data.frame(matrix(ncol=2, nrow=11))
     colnames(MetaData) <- c("name", "value")
     MetaData[1, ] <- c("Db type", "EnsDb")
@@ -1075,7 +1084,7 @@ buildMetadata <- function(organism="", ensemblVersion="", genomeVersion="",
     MetaData[8, ] <- c("ensembl_host", host)
     MetaData[9, ] <- c("Organism", organism )
     MetaData[10, ] <- c("genome_build", genomeVersion)
-    MetaData[11, ] <- c("DBSCHEMAVERSION", "1.0")
+    MetaData[11, ] <- c("DBSCHEMAVERSION", schema)
     MetaData[12, ] <- c("source_file", sourceFile)
     return(MetaData)
 }
@@ -1721,3 +1730,14 @@ elementFromEnsemblFilename <- function(x, which=1){
     return(tmp)
 }
 
+#' Utility function to read lines from a compressed file. While pure `readLines`
+#' works on local files it fails on remote files.
+#'
+#' @noRd
+.read_lines_compressed <- function(x, n = 10) {
+    if (length(grep(".gz$", x, ignore.case = TRUE)))
+        con <- gzcon(file(x, open = "rb"))
+    else con <- file(x, open = "rb")
+    on.exit(suppressWarnings(close(con)))
+    readLines(con, n = n)
+}
