@@ -15,12 +15,20 @@ test_that("ensDbFromGRanges works", {
                                organism="Homo_sapiens", skip = TRUE)
     )
     db <- EnsDb(DB)
+    expect_true(.has_tx_external_name(db))
     expect_equal(unname(genome(db)), "GRCh37")
+    txs <- transcripts(db)
+    expect_true(all(txs$tx_id == txs$tx_name))
 
     Test <- makeEnsembldbPackage(DB, destDir = tempdir(),
                                  version = "0.0.1", author = "J Rainer",
                                  maintainer = "")
-    expect_true(ensembldb:::checkValidEnsDb(db))
+    expect_true(checkValidEnsDb(db))
+    expect_equal(ensDbColumn(TxNameFilter("a"), db), "tx.tx_id")
+    expect_equal(ensDbColumn(TxExternalNameFilter("a"), db),
+                 "tx.tx_external_name")
+    expect_equal(ensDbQuery(TxExternalNameFilter("a"), db),
+                 "tx.tx_external_name = 'a'")
 })
 
 test_that("ensDbFromGtf and Gff works", {
@@ -233,3 +241,20 @@ test_that("getSeqlengthsFromMysqlFolder works", {
         expect_equal(sl, sl_2[names(sl)])
     }
 })
+
+test_that(".read_lines_compressed works", {
+    fl <- system.file("gtf/Devosia_geojensis.ASM96941v1.32.gtf.gz",
+                      package = "ensembldb")
+    res <- readLines(fl, n = 10)
+
+    res_2 <- .read_lines_compressed(fl, n = 10)
+    expect_equal(res_2[1L], "#!genome-build ASM96941v1")
+
+    fl <- paste0(
+        "ftp://ftp.ensembl.org/pub/release-102/gtf/",
+        "homo_sapiens/Homo_sapiens.GRCh38.102.gtf.gz"
+    )
+    expect_warning(res <- readLines(fl, n = 2))
+    res_2 <- .read_lines_compressed(fl, n = 2)
+    expect_equal(res_2[1L], "#!genome-build GRCh38.p13")
+})
